#include <stdlib.h>
#include <string.h>
#include <netcdf.h>
#include <SDL.h>
#include "anugavis.h"
#include "error.h"
#include "globals.h"
#include "height_quantity.h"

int AnugaVis_DefineHeightQuantity(const char *name,
				  double offset, double scale,
				  int red, int green, int blue){
  struct height_quantity_simple *height;
  int ncstatus;
  int ncvarid;
  int numdims;
  /* Check that it's actually in the NetCDF file */
  if((ncstatus = nc_inq_varid(anugavis.netcdfId, name, &ncvarid)) != NC_NOERR){
    AnugaVis_NetCDFError(ncstatus);
    return -1;
  }     

  /* Redefining a quantity? */
  for(height = anugavis.heights ; height != NULL ; height = height->next)
    if(!strcmp(name, height->name)) break;

  if(height == NULL){ /* Make a new entry. */
    if((height = malloc(sizeof(struct height_quantity_simple))) == NULL){
      AnugaVis_SetError("Failed to malloc %d bytes in "
			"AnugaVis_DefineHeightQuantity()",
			sizeof(struct height_quantity_simple));
      return -1;
    }
    height->next = anugavis.heights;
    anugavis.heights = height;
  }
  
  /* If the NetCDF variable is 2-dimensional, then it's dynamic. */
  if((ncstatus = nc_inq_varndims(anugavis.netcdfId,
				 ncvarid, &numdims)) != NC_NOERR){
    AnugaVis_NetCDFError(ncstatus);
    return -1;
  }
  height->dynamic = (numdims == 2);
  height->offset = offset;
  height->scale = scale;
  height->color = SDL_MapRGB(anugavis.screen->format, red, green, blue);
  return 0;
}

void AnugaVis_UndefineHeightQuantity(char *name){
  struct height_quantity_simple *height = anugavis.heights;
  struct height_quantity_simple *nextHeight;
  if(height == NULL) return;
  if(!strcmp(name, height->name)){
    anugavis.heights = height->next;
    free(height);
    return;
  }
  for(; height != NULL ; height = height->next)
    if(height->next == NULL) return;
    if(!strcmp(name, height->next->name)){
      nextHeight = height->next;
      height->next = height->next->next;
      free(nextHeight);
      return;
    }
}
