#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#ifdef HAVE_GL_GL_H
#  include <GL/gl.h>
#elif HAVE_OPENGL_GL_H
#  include <OpenGL/gl.h>
#endif
#ifdef HAVE_GL_GLU_H
#  include <GL/glu.h>
#elif HAVE_OPENGL_GLU_H
#  include <OpenGL/glu.h>
#endif
#include <netcdf.h>
#include <SDL.h>
#include "anugavis.h"
#include "error.h"
#include "globals.h"

int AnugaVis_Init(int width, int height, const char *swwFilePath){
  int ncstatus;
  if((SDL_Init(SDL_INIT_VIDEO) == -1) ||
     (SDL_GL_SetAttribute(SDL_GL_RED_SIZE, 5) == -1) ||
     (SDL_GL_SetAttribute(SDL_GL_GREEN_SIZE, 5) == -1) ||
     (SDL_GL_SetAttribute(SDL_GL_BLUE_SIZE, 5) == -1) ||
     (SDL_GL_SetAttribute(SDL_GL_DEPTH_SIZE, 16) == -1) ||
     (SDL_GL_SetAttribute(SDL_GL_DOUBLEBUFFER, 1) == -1) ||
     ((anugavis.screen = 
       SDL_SetVideoMode(width, height, 16, SDL_OPENGL)) == NULL)){
    AnugaVis_SDLError();
    return -1;
  }

  glEnable(GL_DEPTH_TEST);
  glShadeModel(GL_FLAT);
  glEnable(GL_NORMALIZE);
  glMatrixMode(GL_PROJECTION);
  gluPerspective(45.0, ((GLdouble)width)/((GLdouble)height), 0.1, 1000);
  glMatrixMode(GL_MODELVIEW);
  glLoadIdentity();

  if((ncstatus = nc_open(swwFilePath, NC_SHARE,
			 &anugavis.netcdfId)) != NC_NOERR){
    AnugaVis_NetCDFError(ncstatus);
    SDL_Quit();
    return -1;
  }
  anugavis.heights = NULL;
  return 0;
}

void AnugaVis_DeInit(void){
  while(anugavis.heights != NULL)
    AnugaVis_UndefineHeightQuantity(anugavis.heights->name);
  nc_close(anugavis.netcdfId);
  SDL_Quit();
}
